Description Usage Arguments Examples
This function allows you to visualize global threatened birds distribution
This function allows you to visualize global migratory birds distribution
This function allows you to visualize global threatened birds and development
1 2 3 4 5 | WorldBankData_function(ans = TRUE)
WorldBankData_function(ans = TRUE)
WorldBankData_function(ans = TRUE)
|
Yes |
Do you want to map bitds? Defaults to TRUE. |
Yes |
Do you want to map migratory? Defaults to TRUE. |
Yes |
Do you want to map gdp and birds? Defaults to TRUE. |
1 2 3 | EnBirdWDI_function()
MigratoryBirdsCount_function()
WorldBankData_function()
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.